==> zio-aws-securityhub_2.13-5.17.157.2-sources.jar: zio/aws/securityhub/model/WafOverrideAction.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.NonEmptyString
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class WafOverrideAction(`type`: Option[NonEmptyString] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.WafOverrideAction = {
    import WafOverrideAction.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.WafOverrideAction
      .builder()
      .optionallyWith(
        `type`.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.securityhub.model.WafOverrideAction.ReadOnly =
    zio.aws.securityhub.model.WafOverrideAction.wrap(buildAwsValue())
}
object WafOverrideAction {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.WafOverrideAction
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.securityhub.model.WafOverrideAction =
      zio.aws.securityhub.model.WafOverrideAction(`type`.map(value => value))
    def `type`: Option[NonEmptyString]
    def getType: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.WafOverrideAction
  ) extends zio.aws.securityhub.model.WafOverrideAction.ReadOnly {
    override val `type`: Option[NonEmptyString] = scala
      .Option(impl.`type`())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.WafOverrideAction
  ): zio.aws.securityhub.model.WafOverrideAction.ReadOnly = new Wrapper(impl)
}

==> zio-aws-securityhub_2.13-5.17.171.1-sources.jar: zio/aws/securityhub/model/WafOverrideAction.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.NonEmptyString
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class WafOverrideAction(
    `type`: Optional[NonEmptyString] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.WafOverrideAction = {
    import WafOverrideAction.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.WafOverrideAction
      .builder()
      .optionallyWith(
        `type`.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.securityhub.model.WafOverrideAction.ReadOnly =
    zio.aws.securityhub.model.WafOverrideAction.wrap(buildAwsValue())
}
object WafOverrideAction {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.WafOverrideAction
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.securityhub.model.WafOverrideAction =
      zio.aws.securityhub.model.WafOverrideAction(`type`.map(value => value))
    def `type`: Optional[NonEmptyString]
    def getType: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.WafOverrideAction
  ) extends zio.aws.securityhub.model.WafOverrideAction.ReadOnly {
    override val `type`: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.`type`())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.WafOverrideAction
  ): zio.aws.securityhub.model.WafOverrideAction.ReadOnly = new Wrapper(impl)
}
